@@ -4,7 +4,6 @@ Called to convert a container into a worker pod for the runpod serverless platfo
 '''
 
 import os
-import json
 from threading import Thread
 
 import aiohttp
@@ -27,7 +26,7 @@ async def start_worker(config):
 
     async with aiohttp.ClientSession(headers=auth_header) as session:
 
-        heartbeat_thread = Thread(target=start_heartbeat, daemon=True)
+        heartbeat_thread = Thread(target=start_heartbeat)
         heartbeat_thread.daemon = True
         heartbeat_thread.start()
 
@@ -47,20 +46,11 @@ async def start_worker(config):
 
             job_result = run_job(config["handler"], job)
 
-            job_data = None
-            try:
-                job_data = json.dumps(job_result, ensure_ascii=False)
-            except Exception as err:  # pylint: disable=broad-except
-                log.error(
-                    f"Error while serializing job result {job['id']}: {err}")
-                job_data = json.dumps(
-                    {"error": "unable to serialize job output"})
-
             # SEND RESULTS
-            await send_result(session, job_data, job)
+            await send_result(session, job_result, job)
 
             set_job_id(None)
 
             if os.environ.get('RUNPOD_WEBHOOK_GET_JOB', None) is None:
                 log.info("Local testing complete, exiting.")
-                return
+                break
